@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: yesod-static
 version: 1.5.0.3
-id: yesod-static-1.5.0.3-e228d221dbf26c118b80758084f60c82
-key: yesod_GRhtUlq12w6GoVA6MjHPMO
+id: yesod-static-1.5.0.3-71477be257ade86c1bcd703e19f5bbaa
+key: yesod_HjTFmpRtdpZGuWKRGGqCy7
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
 stability: Stable
@@ -23,21 +23,21 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-static-1.5.0.3
 library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-static-1.5.0.3
 data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-static-1.5.0.3
-hs-libraries: HSyesod-static-1.5.0.3-GRhtUlq12w6GoVA6MjHPMO
+hs-libraries: HSyesod-static-1.5.0.3-HjTFmpRtdpZGuWKRGGqCy7
 depends:
     async-2.1.0-b35f12010d11213b63d33c4f0cc6089c
-    attoparsec-0.13.0.1-cc18275e376dae94cc21e54b8b072afd
+    attoparsec-0.13.0.1-c82a92403ed30683a5cb6228370c626c
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
     blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
     byteable-0.1.1-b91304cc70dc43f4dc186dc9711b3917
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    conduit-1.2.6.2-e9736ac2851958c9940f374454cdc4fe
-    conduit-extra-1.1.10.1-e4383b2e14cc80179dd5007ca51887df
+    conduit-1.2.6.3-0e2837c15036cd2e0c379e7f893dd487
+    conduit-extra-1.1.11-c734df1add5fd1001eeb71b770cb5cb3
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     cryptohash-0.11.7-d9e0f8e58e69d0717d29fde3802983d0
-    cryptohash-conduit-0.1.1-9de27027fde4769c987c6d79fca939a3
-    css-text-0.1.2.1-9e91a6e24ab9d04d01b694bbf376f115
+    cryptohash-conduit-0.1.1-4ac10775feb2347dbaf7d3cc1009a7f7
+    css-text-0.1.2.1-44ac19493562c9a35faccdcd0341bb88
     data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
     file-embed-0.0.9.1-490f794ac7ce2cc242aa3be8fec9767e
@@ -48,15 +48,15 @@ depends:
     mime-types-0.1.0.6-1ae582cd69235deb20f7c2577dd8b3dc
     old-time-1.1.0.3-91625432bd7c61d043f9b743fb82dcf7
     process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
-    resourcet-1.1.7.2-b95e5d14f30eaa21587bc62eeb9aed0c
+    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
     text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     unix-compat-0.4.1.4-baa19ce04d0e8a47661438a80ea2aec8
     unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
     wai-3.2.0-61d8ab991e10dd6c5057d0dabf632d2a
-    wai-app-static-3.1.4.1-5d5bb24da470126a4cd2d84387cf1b92
-    yesod-core-1.4.19-ac3f1cf7050a843b1fae43913e33aa84
+    wai-app-static-3.1.4.1-208aa7b4b78ca13bfed7179fd24989e1
+    yesod-core-1.4.19-1b35f3e0bc5edf244c8b12abed4fd6c1
 haddock-interfaces: /usr/share/doc/haskell-yesod-static/html/yesod-static.haddock
 haddock-html: /usr/share/doc/haskell-yesod-static/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
